@@ -6,7 +6,9 @@ use serde_json;
 pub struct Config {
     _host: String,
     _port: u16,
-    _connection_string: String
+    _connection_string: String,
+    _jwt_secret_key: String,
+    _jwt_expiration_time_in_hours: i64 
 }
 
 impl Config { 
@@ -14,7 +16,13 @@ impl Config {
         let config_file_name = "config.json";
         let config_json = fs::read_to_string(config_file_name)?;
         let config_dto: ConfigDto = serde_json::from_str(&config_json)?;
-        Ok(Config {_host: config_dto.host, _port: config_dto.port, _connection_string: config_dto.connection_string})
+        Ok(Config {
+            _host: config_dto.host, 
+            _port: config_dto.port,
+            _connection_string: config_dto.connection_string,
+            _jwt_secret_key: config_dto.jwt_secret_key,
+            _jwt_expiration_time_in_hours: config_dto.jwt_expiration_time_in_hours
+        })
     }
 
     pub fn host(&self) -> &str { &self._host }
@@ -22,12 +30,18 @@ impl Config {
     pub fn port(&self) -> u16 { self._port }
 
     pub fn connection_string(&self) -> &str { &self._connection_string }
+
+    pub fn jwt_secret_key(&self) -> &str { &self._jwt_secret_key }
+
+    pub fn jwt_expiration_time_in_hours(&self) -> &i64 { &self._jwt_expiration_time_in_hours }
 }
 
 #[derive(Serialize, Deserialize, Debug)]
 struct ConfigDto {
     host: String,
     port: u16, 
-    connection_string: String
+    connection_string: String,
+    jwt_secret_key: String,
+    jwt_expiration_time_in_hours: i64 
 }
 
